KDE 3.5.0, the beginning...

(samba/cups subpackages to fix library issues)
This commit is contained in:
espie 2005-11-29 14:00:11 +00:00
parent 352d48ff22
commit c3e047e90b
28 changed files with 765 additions and 557 deletions

View File

@ -1,10 +1,10 @@
# $OpenBSD: Makefile,v 1.43 2005/10/17 11:28:24 espie Exp $
# $OpenBSD: Makefile,v 1.44 2005/11/29 14:00:11 espie Exp $
COMMENT= "K Desktop Environment, aRTs"
CATEGORIES= x11 x11/kde
VERSION= 3.4.3
DISTNAME= arts-1.4.3
MODKDE_VERSION?= 3.4
VERSION= 3.5.0
DISTNAME= arts-1.5.0
MODKDE_VERSION?= 3.5
PKGNAME= ${DISTNAME}
SHARED_ONLY= No

View File

@ -1,4 +1,4 @@
MD5 (kde/arts-1.4.3.tar.bz2) = 58585969a9a33784601122c77bd15a1e
RMD160 (kde/arts-1.4.3.tar.bz2) = 2c55aaa189fca2ea99854c00d31367fe8b437d72
SHA1 (kde/arts-1.4.3.tar.bz2) = 2af4c342508e72ba09133e9e58f02228bfcddf17
SIZE (kde/arts-1.4.3.tar.bz2) = 945025
MD5 (kde/arts-1.5.0.tar.bz2) = e90a32ee47d5cdc51fe1b7f6f6c0df63
RMD160 (kde/arts-1.5.0.tar.bz2) = dc0532bc7046c12fe8b8d1f88477fd0f34881806
SHA1 (kde/arts-1.5.0.tar.bz2) = 00ede5bf5852aeb6edaadf6f20109710383b28e6
SIZE (kde/arts-1.5.0.tar.bz2) = 949415

View File

@ -1,17 +0,0 @@
$OpenBSD: patch-mcopidl_mcopidl_cc,v 1.1 2005/04/11 22:54:33 espie Exp $
--- mcopidl/mcopidl.cc.orig Tue Apr 12 00:45:51 2005
+++ mcopidl/mcopidl.cc Tue Apr 12 00:48:37 2005
@@ -122,12 +122,12 @@ void startInclude( const char *line )
char *b = strtok(0,">\"");
if(b) file = b;
}
- free(l);
idl_in_include++;
idl_include_stack.push(make_pair(idl_line_no, idl_filename));
idl_line_no = 0;
idl_filename = file;
+ free(l);
}
void endInclude()

View File

@ -1,20 +1,44 @@
# $OpenBSD: Makefile,v 1.48 2005/11/11 11:33:01 espie Exp $
# $OpenBSD: Makefile,v 1.49 2005/11/29 14:00:12 espie Exp $
COMMENT= "K Desktop Environment, basic applications"
COMMENT-plugins= "Konqueror nsplugins, essentially native JDK"
COMMENT-samba= "K Desktop Environment, samba support"
CATEGORIES= x11 x11/kde
VERSION= 3.4.3
VERSION= 3.5.0
DISTNAME= kdebase-${VERSION}
PKGNAME= ${DISTNAME}p2
MODKDE_VERSION?= 3.4
PKGNAME= ${DISTNAME}
PKGNAME-samba= kdesamba-${VERSION}
MODKDE_VERSION?= 3.5
MULTI_PACKAGES= -samba
SUBPACKAGE?=
FLAVORS= debug
LIB_DEPENDS= kdecore.6,kabc,katepartinterfaces,kdefakes,kdefx,kdnssd,kdeprint,kdeprint_management,kdesu,kdeui,khtml,kio,kjs,knewstuff,kmid,kmdi2,kparts,kresources,kscreensaver,kscript,ktexteditor,kutils,kwalletclient,DCOP,vcard,artskde::x11/kde/libs3 \
BUILD_DEPENDS+=::devel/pkgconfig
WANTLIB+=ICE Xrender SM pthread util X11 m z png jpeg art_lgpl_2 Xext
.if !defined(PACKAGING) || ${SUBPACKAGE:L} == ""
LIB_DEPENDS+= kdecore.6,kabc,katepartinterfaces,kdefakes,kdefx,kdnssd,kdeprint,kdeprint_management,kdesu,kdeui,khtml,kio,kjs,knewstuff,kmid,kparts,kresources,kscreensaver,ktexteditor,kutils,kwalletclient,DCOP,vcard,artskde::x11/kde/libs3 \
lber,ldap.2:openldap-client-2.*:databases/openldap \
sasl2::security/cyrus-sasl2 \
usb::devel/libusb
LIB_DEPENDS+= \
glib-2.0.0.0,gmodule-2.0.0.0,gthread-2.0.0.0::devel/glib2
WANTLIB+= Xcursor Xrandr Xss Xt Xtst Xxf86misc \
artsflow artsflow_idl audiofile c crypto esd \
freetype iconv intl kmedia2_idl mad mcop ogg ossaudio \
pcre pcreposix qtmcop soundserver_idl ssl stdc++ \
vorbis vorbisenc vorbisfile xkbfile GLU fontenc \
Xinerama Xft Xfixes fontconfig GL Xcomposite Xdamage \
Half Imath IlmImf Iex
BUILD_DEPENDS+=::devel/pkgconfig
.endif
.if !defined(PACKAGING) || ${SUBPACKAGE:L} == "-samba"
LIB_DEPENDS+= lib/samba/smbclient:samba->=3:net/samba
LIB_DEPENDS+= DCOP,kdecore.6,kio,kdeui,kdefx,kdesu,kwalletclient::x11/kde/libs3
.endif
SEPARATE_BUILD= flavored
EXTRA_CONFIG= xdg/menus/kde-settings.menu \
@ -23,13 +47,6 @@ EXTRA_CONFIG= xdg/menus/kde-settings.menu \
xdg/menus/applications-merged/kde-essential.menu \
ksysguarddrc
LIB_DEPENDS+= \
glib-2.0.0.0,gmodule-2.0.0.0,gthread-2.0.0.0::devel/glib2
.if !defined(PACKAGING)
LIB_DEPENDS+= lib/samba/smbclient:samba->=3:net/samba
.endif
CONFIGURE_ENV+= PKG_CONFIG_PATH=${X11BASE}/lib/pkgconfig
@ -44,13 +61,6 @@ post-install:
FAKE_FLAGS=DESTDIR=${WRKINST} sysconfdir=${SAMPLECONFDIR}
#CONFIGURE_ARGS+=--without-motif
WANTLIB= ICE SM X11 Xcursor Xext Xrandr Xrender Xss Xt Xtst Xxf86misc \
art_lgpl_2 artsflow artsflow_idl audiofile c crypto esd \
freetype iconv intl jpeg kmedia2_idl m mad mcop ogg ossaudio \
pcre pcreposix png pthread qtmcop soundserver_idl ssl stdc++ \
util vorbis vorbisenc vorbisfile xkbfile z GLU fontenc \
Xinerama Xft Xfixes fontconfig GL Xcomposite Xdamage \
Half Imath IlmImf Iex
#CONFIGURE_ARGS+=--without-samba
.include <bsd.port.mk>

View File

@ -1,4 +1,4 @@
MD5 (kde/kdebase-3.4.3.tar.bz2) = 7b25feba2774c077601d472dae5352c8
RMD160 (kde/kdebase-3.4.3.tar.bz2) = 7af02903b0fc750e7b9778391ef8948b54f69ce7
SHA1 (kde/kdebase-3.4.3.tar.bz2) = 87b72aaf291fdb78fa9feb9acf4476d41485e486
SIZE (kde/kdebase-3.4.3.tar.bz2) = 22425835
MD5 (kde/kdebase-3.5.0.tar.bz2) = b86622c029ee8ab656a67c6467fff887
RMD160 (kde/kdebase-3.5.0.tar.bz2) = 5f8d5735a468f1c4e42cccfc0f006e63e3c3c762
SHA1 (kde/kdebase-3.5.0.tar.bz2) = 8826fdd8884151cf224442da78d23d5685bd21e9
SIZE (kde/kdebase-3.5.0.tar.bz2) = 23233185

View File

@ -1,20 +0,0 @@
$OpenBSD: patch-configure_in,v 1.16 2005/11/11 11:33:02 espie Exp $
--- configure.in.orig Wed Oct 5 23:39:40 2005
+++ configure.in Fri Nov 11 12:17:19 2005
@@ -593,6 +593,7 @@ if test "$KFI_FOUND_FREETYPE" -eq 1; the
*-*-aix*) UNAME='AIX' ;;
*-*-hpux*) UNAME='HPUX' ;;
*-*-darwin*) UNAME='Darwin' ;;
+ *-*-openbsd*) UNAME='OpenBSD';;
*) UNAME='Unknown' ;;
esac
AC_MSG_RESULT($UNAME)
@@ -1265,7 +1266,7 @@ if test "x$with_ldap" = "xCHECK" ; then
LDAP_LIBS="-L$ldap_libdir "
test "$USE_RPATH" = yes && LDAP_RPATH="-R $ldap_libdir"
fi
- LDAP_LIBS="${LDAP_LIBS}-lldap -llber ${LIBRESOLV}"
+ LDAP_LIBS="${LDAP_LIBS}-lldap -llber ${SASL2_LIBS} ${LIBRESOLV}"
with_ldap=FOUND
break
fi

View File

@ -1,89 +0,0 @@
$OpenBSD: patch-kcontrol_clock_tzone_cpp,v 1.2 2004/02/01 14:59:22 espie Exp $
--- kcontrol/clock/tzone.cpp.orig 2004-01-17 13:47:47.000000000 +0100
+++ kcontrol/clock/tzone.cpp 2004-01-21 01:20:49.000000000 +0100
@@ -50,8 +50,14 @@
#include <sys/stat.h>
#define ZONEINFODIR "/usr/share/lib/zoneinfo"
+#define FIND_BINARY "/bin/find"
#define INITFILE "/etc/default/init"
#endif
+#ifdef __OpenBSD__
+#define ZONEINFODIR "/usr/share/zoneinfo"
+#define FIND_BINARY "/usr/bin/find"
+#include <sys/param.h>
+#endif
Tzone::Tzone(QWidget * parent, const char *name)
: QGroupBox(parent, name)
@@ -86,14 +92,15 @@ void Tzone::fillTimeZones()
tzonelist->insertItem(i18n("[No selection]"));
-#if defined(USE_SOLARIS) // MARCO
+#if defined(USE_SOLARIS) || defined(__OpenBSD__) // MARCO
FILE *fp;
char buf[MAXPATHLEN];
+ char *p = buf + strlen(ZONEINFODIR) + 1;
snprintf(buf, MAXPATHLEN,
- "/bin/find %s \\( -name src -prune \\) -o -type f -print | /bin/cut -b %d-",
- ZONEINFODIR, strlen(ZONEINFODIR) + 2);
+ "%s %s \\( -name src -prune \\) -o -type f -print",
+ FIND_BINARY, ZONEINFODIR);
fp = popen(buf, "r");
if (fp)
@@ -101,8 +108,8 @@ void Tzone::fillTimeZones()
while(fgets(buf, MAXPATHLEN - 1, fp) != NULL)
{
buf[strlen(buf) - 1] = '\0';
- list << i18n(buf);
- tzonenames << buf;
+ list << i18n(p);
+ tzonenames << p;
}
pclose(fp);
}
@@ -166,6 +173,14 @@ void Tzone::load()
}
pclose(fp);
}
+#elif defined(__OpenBSD__)
+ char buffer[MAXPATHLEN];
+ int n;
+ n = readlink("/etc/localtime", buffer, sizeof(buffer)-1);
+ if (n != -1) {
+ buffer[n] = 0;
+ sCurrentlySet = buffer + strlen(ZONEINFODIR)+1;
+ }
#else
QFile f("/etc/timezone");
if(f.open(IO_ReadOnly))
@@ -264,6 +279,7 @@ void Tzone::save()
QString val = selectedzone;
#else
+#if !defined(__OpenBSD__)
QFile fTimezoneFile("/etc/timezone");
if (fTimezoneFile.open(IO_WriteOnly | IO_Truncate) )
@@ -273,6 +289,7 @@ void Tzone::save()
fTimezoneFile.close();
}
+#endif
tz = "/usr/share/zoneinfo/" + selectedzone;
kdDebug() << "Set time zone " << tz << endl;
@@ -294,7 +311,9 @@ void Tzone::save()
} else {
#if !defined(USE_SOLARIS) // Do not update the System!
+#if !defined(__OpenBSD__)
unlink( "/etc/timezone" );
+#endif
unlink( "/etc/localtime" );
setenv("TZ", "", 1);

View File

@ -1,7 +1,7 @@
$OpenBSD: patch-kdm_kfrontend_Makefile_in,v 1.13 2005/10/17 11:28:24 espie Exp $
--- kdm/kfrontend/Makefile.in.orig Wed Oct 5 23:44:50 2005
+++ kdm/kfrontend/Makefile.in Sun Oct 9 00:12:09 2005
@@ -1109,7 +1109,7 @@ uninstall-info: uninstall-info-recursive
$OpenBSD: patch-kdm_kfrontend_Makefile_in,v 1.14 2005/11/29 14:00:12 espie Exp $
--- kdm/kfrontend/Makefile.in.orig Sun Nov 20 21:46:02 2005
+++ kdm/kfrontend/Makefile.in Mon Nov 21 14:25:33 2005
@@ -1125,7 +1125,7 @@ uninstall-info: uninstall-info-recursive
install-data-local: genkdmconf

View File

@ -1,7 +1,7 @@
$OpenBSD: patch-kioslave_man_man2html_cpp,v 1.10 2005/03/29 21:18:35 espie Exp $
--- kioslave/man/man2html.cpp.orig Wed Feb 23 12:26:40 2005
+++ kioslave/man/man2html.cpp Wed Mar 23 11:50:59 2005
@@ -1918,6 +1918,7 @@ static const char *section_list[] = {
$OpenBSD: patch-kioslave_man_man2html_cpp,v 1.11 2005/11/29 14:00:12 espie Exp $
--- kioslave/man/man2html.cpp.orig Tue Nov 8 23:36:08 2005
+++ kioslave/man/man2html.cpp Mon Nov 21 14:25:00 2005
@@ -2696,6 +2696,7 @@ static const char *section_list[] = {
"3L", "Lightweight Processes Library",
"3M", "Mathematical Library",
"3N", "Network Functions",
@ -9,7 +9,7 @@ $OpenBSD: patch-kioslave_man_man2html_cpp,v 1.10 2005/03/29 21:18:35 espie Exp $
"3R", "RPC Services Library",
"3S", "Standard I/O Functions",
"3V", "C Library Functions",
@@ -4019,16 +4020,17 @@ static char *scan_troff_mandoc(char *c,
@@ -5460,16 +5461,17 @@ static char *scan_troff_mandoc(char *c,
end++;
}

View File

@ -1,8 +1,8 @@
$OpenBSD: patch-startkde,v 1.11 2005/10/17 11:28:24 espie Exp $
--- startkde.orig Wed Oct 5 15:41:59 2005
+++ startkde Sun Oct 9 00:11:31 2005
$OpenBSD: patch-startkde,v 1.12 2005/11/29 14:00:12 espie Exp $
--- startkde.orig Tue Nov 8 23:37:01 2005
+++ startkde Mon Nov 21 14:25:00 2005
@@ -3,6 +3,11 @@
# DEFAULT KDE STARTUP SCRIPT ( KDE-3.4.3 )
# DEFAULT KDE STARTUP SCRIPT ( KDE-3.5 )
#
+case X"$DISPLAY" in

View File

@ -73,5 +73,4 @@ over on your .kde files. Managing legacy config files is quite buggy yet.
a recent JVM installed, and referenced from Konqueror's menu, for Java to
work.
- samba share do only work is you install samba. There is no hard coded
dependency on samba, though...
- install kdesamba if you need to access samba shares.

View File

@ -0,0 +1,7 @@
KDE is a network transparent contemporary desktop environment for UNIX
workstations. It was written by a world-wide network of software
engineers committed to free software development. KDE seeks to fill
the need for an easy to use desktop for Unix workstations, similar to
the desktop environments found under the MacOS or Window95/NT.
This package holds the samba glue for kde.

File diff suppressed because it is too large Load Diff

View File

@ -0,0 +1,12 @@
@comment $OpenBSD: PLIST-samba,v 1.1 2005/11/29 14:00:13 espie Exp $
@conflict kdebase-<3.5
${KDE}/kio_smb.la
${KDE}/kio_smb.so
share/apps/konqueror/dirtree/
share/apps/konqueror/dirtree/remote/
share/apps/konqueror/dirtree/remote/smb-network.desktop
share/apps/remoteview/
share/apps/remoteview/smb-network.desktop
share/mimelnk/application/x-smb-server.desktop
share/mimelnk/application/x-smb-workgroup.desktop
share/services/smb.protocol

View File

@ -1,34 +1,56 @@
# $OpenBSD: Makefile,v 1.58 2005/10/17 11:28:25 espie Exp $
# $OpenBSD: Makefile,v 1.59 2005/11/29 14:00:12 espie Exp $
COMMENT= "K Desktop Environment, libraries"
COMMENT-cups= "K Desktop Environment, cups support"
CATEGORIES= x11 x11/kde
VERSION= 3.4.3
VERSION= 3.5.0
DISTNAME= kdelibs-${VERSION}
PKGNAME= ${DISTNAME}
MODKDE_VERSION?= 3.4
PKGNAME-cups= kdecups-${VERSION}
MODKDE_VERSION?= 3.5
FLAVORS=debug
VMEM_WARNING= Yes
LIB_DEPENDS= art_lgpl_2::graphics/libart \
artsflow.1.0,artsflow_idl,qtmcop,soundserver_idl,mcop,kmedia2_idl::x11/kde/arts3 \
MULTI_PACKAGES= -cups
CONFIGURE_ARGS+= --enable-cups
SUBPACKAGE?=
BUILD_DEPENDS+= ::textproc/docbook-to-man \
::devel/pkgconfig
LIB_DEPENDS+= art_lgpl_2::graphics/libart
WANTLIB+= intl iconv util jpeg m X11 ICE Xrender c SM pthread \
stdc++ Xext z png
.if !defined(PACKAGING) || ${SUBPACKAGE:L} == ""
LIB_DEPENDS+= artsflow.1.0,artsflow_idl,qtmcop,soundserver_idl,mcop,kmedia2_idl::x11/kde/arts3 \
pcreposix,pcre::devel/pcre \
xslt.1.10:libxslt->=1.0.10:textproc/libxslt \
bz2::archivers/bzip2 \
tiff.35::graphics/tiff \
jasper::graphics/jasper
WANTLIB= c ICE SM X11 Xext Xrender audiofile esd glib-2.0.0.0 \
gmodule-2.0.0.0 gthread-2.0.0.0 iconv intl jpeg m mad ogg \
ossaudio png pthread stdc++ util vorbis vorbisenc vorbisfile \
xml2 z krb5 gssapi ssl crypto asn1
WANTLIB+= audiofile esd glib-2.0.0.0 \
gmodule-2.0.0.0 gthread-2.0.0.0 mad ogg \
ossaudio vorbisenc vorbis vorbisfile \
xml2 krb5 gssapi crypto asn1
CONFIGURE_ARGS+= --enable-cups
BUILD_DEPENDS+= ::print/cups # crypto,ssl,cups
BUILD_DEPENDS+= ::textproc/docbook-to-man \
::devel/pkgconfig
LIB_DEPENDS+= Half,Iex,Imath,IlmImf::graphics/openexr \
aspell::textproc/aspell/core
.endif
.if !defined(PACKAGING) || ${SUBPACKAGE:L} == "-cups"
LIB_DEPENDS+= cups::print/cups
WANTLIB+= gcrypt gnutls gpg-error
.endif
.if defined(PACKAGING) && ${SUBPACKAGE:L} == "-cups"
LIB_DEPENDS+= kdecore.6,kwalletclient,kdefakes,kdefx,kdeprint,kio,kparts,kdeui,kdesu,kdeprint_management,DCOP::x11/kde/libs3
.endif
SEPARATE_BUILD= flavored
SAMPLECONFDIR=${TRUEPREFIX}/share/apps/kde-conf-sample

View File

@ -1,4 +1,4 @@
MD5 (kde/kdelibs-3.4.3.tar.bz2) = 0cd7c0c8a81e5d11b91b407a4aaaf3ff
RMD160 (kde/kdelibs-3.4.3.tar.bz2) = 3bf89c0694f0fbabe46ae75d49f3eaf651fc2a90
SHA1 (kde/kdelibs-3.4.3.tar.bz2) = ab701b90efc9cfe29e8e9c461d8b8c82357d8ef7
SIZE (kde/kdelibs-3.4.3.tar.bz2) = 16877867
MD5 (kde/kdelibs-3.5.0.tar.bz2) = 2b11d654e2ea1a3cd16dcfdcbb7d1915
RMD160 (kde/kdelibs-3.5.0.tar.bz2) = a170428a7166f322ab86d1c0280f12e23a8f6df3
SHA1 (kde/kdelibs-3.5.0.tar.bz2) = c03bc6b09add3c487b3e28a5fb1d89efd30a9723
SIZE (kde/kdelibs-3.5.0.tar.bz2) = 15379557

View File

@ -1,7 +1,7 @@
$OpenBSD: patch-configure_in,v 1.21 2005/10/17 11:28:25 espie Exp $
--- configure.in.orig Wed Oct 5 23:49:43 2005
+++ configure.in Mon Oct 17 12:27:07 2005
@@ -1796,7 +1796,7 @@ dnl ====================================
$OpenBSD: patch-configure_in,v 1.22 2005/11/29 14:00:12 espie Exp $
--- configure.in.orig Mon Nov 21 10:06:55 2005
+++ configure.in Mon Nov 21 12:00:07 2005
@@ -1938,7 +1938,7 @@ dnl ====================================
AC_LANG_SAVE
AC_LANG_C
dnl Check for aspell library

View File

@ -1,7 +1,7 @@
$OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.8 2005/06/14 02:01:25 espie Exp $
--- kdecore/network/kresolver.cpp.orig Mon May 23 14:16:17 2005
+++ kdecore/network/kresolver.cpp Tue Jun 14 03:37:23 2005
@@ -64,6 +64,10 @@
$OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.9 2005/11/29 14:00:12 espie Exp $
--- kdecore/network/kresolver.cpp.orig Mon Oct 10 17:06:02 2005
+++ kdecore/network/kresolver.cpp Mon Nov 21 12:00:08 2005
@@ -66,6 +66,10 @@
QMutex getXXbyYYmutex;
#endif
@ -12,7 +12,7 @@ $OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.8 2005/06/14 02:01:25 espie Ex
using namespace KNetwork;
using namespace KNetwork::Internal;
@@ -614,17 +618,28 @@ QStrList KResolver::protocolName(int pro
@@ -616,17 +620,28 @@ QStrList KResolver::protocolName(int pro
pe = getprotobynumber(protonum);
#else
@ -44,7 +44,7 @@ $OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.8 2005/06/14 02:01:25 espie Ex
{
buflen += 1024;
delete [] buf;
@@ -633,6 +648,7 @@ QStrList KResolver::protocolName(int pro
@@ -635,6 +650,7 @@ QStrList KResolver::protocolName(int pro
break;
}
while (pe == 0L);
@ -52,7 +52,7 @@ $OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.8 2005/06/14 02:01:25 espie Ex
#endif
// Do common processing
@@ -645,7 +661,9 @@ QStrList KResolver::protocolName(int pro
@@ -647,7 +663,9 @@ QStrList KResolver::protocolName(int pro
}
#ifdef HAVE_GETPROTOBYNAME_R
@ -62,7 +62,7 @@ $OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.8 2005/06/14 02:01:25 espie Ex
#endif
return lst;
@@ -660,17 +678,27 @@ QStrList KResolver::protocolName(const c
@@ -662,17 +680,27 @@ QStrList KResolver::protocolName(const c
pe = getprotobyname(protoname);
#else
@ -93,7 +93,7 @@ $OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.8 2005/06/14 02:01:25 espie Ex
{
buflen += 1024;
delete [] buf;
@@ -679,6 +707,7 @@ QStrList KResolver::protocolName(const c
@@ -681,6 +709,7 @@ QStrList KResolver::protocolName(const c
break;
}
while (pe == 0L);
@ -101,7 +101,7 @@ $OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.8 2005/06/14 02:01:25 espie Ex
#endif
// Do common processing
@@ -691,7 +720,9 @@ QStrList KResolver::protocolName(const c
@@ -693,7 +722,9 @@ QStrList KResolver::protocolName(const c
}
#ifdef HAVE_GETPROTOBYNAME_R
@ -111,7 +111,7 @@ $OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.8 2005/06/14 02:01:25 espie Ex
#endif
return lst;
@@ -706,17 +737,28 @@ int KResolver::protocolNumber(const char
@@ -708,17 +739,28 @@ int KResolver::protocolNumber(const char
pe = getprotobyname(protoname);
#else
@ -143,7 +143,7 @@ $OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.8 2005/06/14 02:01:25 espie Ex
{
buflen += 1024;
delete [] buf;
@@ -725,6 +767,7 @@ int KResolver::protocolNumber(const char
@@ -727,6 +769,7 @@ int KResolver::protocolNumber(const char
break;
}
while (pe == 0L);
@ -151,7 +151,7 @@ $OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.8 2005/06/14 02:01:25 espie Ex
#endif
// Do common processing
@@ -733,7 +776,9 @@ int KResolver::protocolNumber(const char
@@ -735,7 +778,9 @@ int KResolver::protocolNumber(const char
protonum = pe->p_proto;
#ifdef HAVE_GETPROTOBYNAME_R
@ -161,7 +161,7 @@ $OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.8 2005/06/14 02:01:25 espie Ex
#endif
return protonum;
@@ -748,17 +793,27 @@ int KResolver::servicePort(const char *s
@@ -750,17 +795,27 @@ int KResolver::servicePort(const char *s
se = getservbyname(servname, protoname);
#else
@ -192,7 +192,7 @@ $OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.8 2005/06/14 02:01:25 espie Ex
{
buflen += 1024;
delete [] buf;
@@ -775,7 +830,9 @@ int KResolver::servicePort(const char *s
@@ -777,7 +832,9 @@ int KResolver::servicePort(const char *s
servport = ntohs(se->s_port);
#ifdef HAVE_GETSERVBYNAME_R
@ -202,7 +202,7 @@ $OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.8 2005/06/14 02:01:25 espie Ex
#endif
return servport;
@@ -790,17 +847,27 @@ QStrList KResolver::serviceName(const ch
@@ -792,17 +849,27 @@ QStrList KResolver::serviceName(const ch
se = getservbyname(servname, protoname);
#else
@ -233,7 +233,7 @@ $OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.8 2005/06/14 02:01:25 espie Ex
{
buflen += 1024;
delete [] buf;
@@ -809,6 +876,7 @@ QStrList KResolver::serviceName(const ch
@@ -811,6 +878,7 @@ QStrList KResolver::serviceName(const ch
break;
}
while (se == 0L);
@ -241,7 +241,7 @@ $OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.8 2005/06/14 02:01:25 espie Ex
#endif
// Do common processing
@@ -821,7 +889,9 @@ QStrList KResolver::serviceName(const ch
@@ -823,7 +891,9 @@ QStrList KResolver::serviceName(const ch
}
#ifdef HAVE_GETSERVBYNAME_R
@ -251,7 +251,7 @@ $OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.8 2005/06/14 02:01:25 espie Ex
#endif
return lst;
@@ -836,17 +906,27 @@ QStrList KResolver::serviceName(int port
@@ -838,17 +908,27 @@ QStrList KResolver::serviceName(int port
se = getservbyport(port, protoname);
#else
@ -282,7 +282,7 @@ $OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.8 2005/06/14 02:01:25 espie Ex
{
buflen += 1024;
delete [] buf;
@@ -855,6 +935,8 @@ QStrList KResolver::serviceName(int port
@@ -857,6 +937,8 @@ QStrList KResolver::serviceName(int port
break;
}
while (se == 0L);
@ -291,7 +291,7 @@ $OpenBSD: patch-kdecore_network_kresolver_cpp,v 1.8 2005/06/14 02:01:25 espie Ex
#endif
// Do common processing
@@ -867,7 +949,9 @@ QStrList KResolver::serviceName(int port
@@ -869,7 +951,9 @@ QStrList KResolver::serviceName(int port
}
#ifdef HAVE_GETSERVBYPORT_R

View File

@ -1,6 +1,6 @@
$OpenBSD: patch-kdesu_su_cpp,v 1.6 2004/09/18 09:36:44 espie Exp $
--- kdesu/su.cpp.orig Sat May 22 22:55:16 2004
+++ kdesu/su.cpp Mon Sep 6 02:36:32 2004
$OpenBSD: patch-kdesu_su_cpp,v 1.7 2005/11/29 14:00:12 espie Exp $
--- kdeui/kmainwindow.cpp.orig Fri Feb 4 00:33:10 2005
+++ kdeui/kmainwindow.cpp Wed Mar 23 09:35:08 2005
@@ -199,7 +199,7 @@ void KMainWindow::initKMainWindow(const
s = objname + '1'; // start adding number immediately
unusedNumber = 1;
}
- else if( name[ strlen( name ) - 1 ] == '#' )
+ else if( strlen( name ) > 0 && name[ strlen( name ) - 1 ] == '#' )
{ // trailing # - always add a number
objname = name;
s = objname + '1'; // start adding number immediately

View File

@ -1,7 +1,7 @@
$OpenBSD: patch-kioslave_ftp_ftp_cc,v 1.2 2005/03/29 21:18:36 espie Exp $
--- kioslave/ftp/ftp.cc.orig Wed Feb 23 12:57:14 2005
+++ kioslave/ftp/ftp.cc Wed Mar 23 09:35:08 2005
@@ -759,6 +759,14 @@ bool Ftp::ftpSendCmd( const QCString& cm
$OpenBSD: patch-kioslave_ftp_ftp_cc,v 1.3 2005/11/29 14:00:12 espie Exp $
--- kioslave/ftp/ftp.cc.orig Mon Oct 10 17:05:36 2005
+++ kioslave/ftp/ftp.cc Mon Nov 21 12:00:08 2005
@@ -756,6 +756,14 @@ bool Ftp::ftpSendCmd( const QCString& cm
return false;
}

View File

@ -5,3 +5,4 @@ the need for an easy to use desktop for Unix workstations, similar to
the desktop environments found under the MacOS or Window95/NT.
This package holds the base libraries necessary for kde3 to work.
Install kdecups as well if you want to use cups within kde.

View File

@ -0,0 +1,7 @@
KDE is a network transparent contemporary desktop environment for UNIX
workstations. It was written by a world-wide network of software
engineers committed to free software development. KDE seeks to fill
the need for an easy to use desktop for Unix workstations, similar to
the desktop environments found under the MacOS or Window95/NT.
This package holds the interface glue for the cups print system.

View File

@ -1,12 +1,10 @@
@comment $OpenBSD: PLIST,v 1.34 2005/10/17 11:28:25 espie Exp $
@conflict kdebase-<3.4
@comment $OpenBSD: PLIST,v 1.35 2005/11/29 14:00:12 espie Exp $
@conflict kdebase-<3.5
@conflict kdeartwork-<3.4
@conflict kdeaddons-<3.4
@conflict kdeadmin-<3.4
bin/artsmessage
bin/checkXML
bin/cupsdconf
bin/cupsdoprint
bin/dcop
bin/dcopclient
bin/dcopfind
@ -38,11 +36,11 @@ bin/kdeinit_wrapper
bin/kdelibtool
bin/kdesu_stub
bin/kdontchangethehostname
bin/kdostartupconfig
bin/kfile
bin/kfmexec
@comment bin/kgrantpty
bin/khotnewstuff
bin/kimage_concat
bin/kinstalltheme
bin/kio_http_cache_cleaner
bin/kio_uiserver
@ -53,12 +51,13 @@ bin/kmailservice
bin/kpac_dhcp_helper
bin/ksendbugmail
bin/kshell
bin/kstartupconfig
bin/ksvgtopng
bin/ktelnetservice
bin/ktradertest
bin/kunittestmodrunner
bin/kwrapper
bin/lnusertemp
bin/make_driver_db_cups
bin/make_driver_db_lpr
bin/makekdewidgets
bin/meinproc
@ -169,6 +168,7 @@ include/kaboutkde.h
include/kaccel.h
include/kaccelgen.h
include/kaccelmanager.h
include/kacl.h
include/kaction.h
include/kactionclasses.h
include/kactioncollection.h
@ -578,6 +578,7 @@ include/kscan.h
include/ksconfig.h
include/kscreensaver.h
include/kscreensaver_vroot.h
include/kscrollview.h
include/kselect.h
include/kseparator.h
include/kserversocket.h
@ -707,6 +708,8 @@ include/ktexteditor/viewcursorinterface.h
include/ktexteditor/viewstatusmsginterface.h
include/ktexteditor/wordwrapinterface.h
include/ktimewidget.h
include/ktimezones.h
include/ktimezonewidget.h
include/ktip.h
include/ktoolbar.h
include/ktoolbarbutton.h
@ -716,6 +719,10 @@ include/ktrader.h
include/ktypelist.h
include/kuniqueapp.h
include/kuniqueapplication.h
include/kunittest/
include/kunittest/module.h
include/kunittest/runner.h
include/kunittest/tester.h
include/kunload.h
include/kurifilter.h
include/kurl.h
@ -771,8 +778,6 @@ include/scriptclientinterface.h
include/scriptinterface.h
include/scriptmanager.h
${KDE}/
${KDE}/cupsdconf.la
${KDE}/cupsdconf.so
${KDE}/dcopserver.la
${KDE}/dcopserver.so
${KDE}/kabc_dir.la
@ -815,8 +820,6 @@ ${KDE}/kded_kwalletd.la
${KDE}/kded_kwalletd.so
${KDE}/kded_proxyscout.la
${KDE}/kded_proxyscout.so
${KDE}/kdeprint_cups.la
${KDE}/kdeprint_cups.so
${KDE}/kdeprint_ext.la
${KDE}/kdeprint_ext.so
${KDE}/kdeprint_lpdunix.la
@ -839,6 +842,8 @@ ${KDE}/kimg_eps.la
${KDE}/kimg_eps.so
${KDE}/kimg_exr.la
${KDE}/kimg_exr.so
${KDE}/kimg_hdr.la
${KDE}/kimg_hdr.so
${KDE}/kimg_ico.la
${KDE}/kimg_ico.so
${KDE}/kimg_jp2.la
@ -883,6 +888,8 @@ ${KDE}/kspell_aspell.la
${KDE}/kspell_aspell.so
${KDE}/kspell_ispell.la
${KDE}/kspell_ispell.so
${KDE}/kstyle_highcontrast_config.la
${KDE}/kstyle_highcontrast_config.so
${KDE}/kstyle_plastik_config.la
${KDE}/kstyle_plastik_config.so
${KDE}/ktexteditor_docwordcompletion.la
@ -945,8 +952,6 @@ lib/libkdefakes.la
lib/libkdefakes_nonpic.a
lib/libkdefx.la
@lib lib/libkdefx.so.6.0
lib/libkdeinit_cupsdconf.la
lib/libkdeinit_cupsdconf.so
lib/libkdeinit_dcopserver.la
lib/libkdeinit_dcopserver.so
lib/libkdeinit_kaddprinterwizard.la
@ -1015,6 +1020,8 @@ lib/libkspell2.la
@lib lib/libkspell2.so.1.0
lib/libktexteditor.la
@lib lib/libktexteditor.so.0.0
lib/libkunittest.la
@lib lib/libkunittest.so.1.0
lib/libkutils.la
@lib lib/libkutils.so.3.0
lib/libkwalletbackend.la
@ -1074,12 +1081,22 @@ share/apps/kabc/formats/binary.desktop
share/apps/katepart/
share/apps/katepart/katepartreadonlyui.rc
share/apps/katepart/katepartui.rc
share/apps/katepart/scripts/
share/apps/katepart/scripts/indent/
share/apps/katepart/scripts/indent/script-indent-c-test.js
share/apps/katepart/scripts/indent/script-indent-c1-test.lua
share/apps/katepart/scripts/jstest.desktop
share/apps/katepart/scripts/jstest.js
share/apps/katepart/scripts/script-indent-c-char.js
share/apps/katepart/scripts/script-indent-c-newline.js
share/apps/katepart/scripts/sort.js
share/apps/katepart/syntax/
share/apps/katepart/syntax/abc.xml
share/apps/katepart/syntax/ada.xml
share/apps/katepart/syntax/ahdl.xml
share/apps/katepart/syntax/alert.xml
share/apps/katepart/syntax/ansic89.xml
share/apps/katepart/syntax/apache.xml
share/apps/katepart/syntax/asm-avr.xml
share/apps/katepart/syntax/asm6502.xml
share/apps/katepart/syntax/asp.xml
@ -1114,6 +1131,7 @@ share/apps/katepart/syntax/ferite.xml
share/apps/katepart/syntax/fgl-4gl.xml
share/apps/katepart/syntax/fgl-per.xml
share/apps/katepart/syntax/fortran.xml
share/apps/katepart/syntax/fstab.xml
share/apps/katepart/syntax/gdl.xml
share/apps/katepart/syntax/gettext.xml
share/apps/katepart/syntax/glsl.xml
@ -1125,6 +1143,7 @@ share/apps/katepart/syntax/idconsole.xml
share/apps/katepart/syntax/idl.xml
share/apps/katepart/syntax/ilerpg.xml
share/apps/katepart/syntax/inform.xml
share/apps/katepart/syntax/ini.xml
share/apps/katepart/syntax/java.xml
share/apps/katepart/syntax/javadoc.xml
share/apps/katepart/syntax/javascript-php.xml
@ -1140,10 +1159,12 @@ share/apps/katepart/syntax/literate-haskell.xml
share/apps/katepart/syntax/logtalk.xml
share/apps/katepart/syntax/lpc.xml
share/apps/katepart/syntax/lua.xml
share/apps/katepart/syntax/m3u.xml
share/apps/katepart/syntax/mab.xml
share/apps/katepart/syntax/makefile.xml
share/apps/katepart/syntax/mason.xml
share/apps/katepart/syntax/matlab.xml
share/apps/katepart/syntax/mediawiki.xml
share/apps/katepart/syntax/mips.xml
share/apps/katepart/syntax/modula-2.xml
share/apps/katepart/syntax/mup.xml
@ -1219,8 +1240,6 @@ share/apps/kde-conf-sample/xdg/menus/applications.menu
share/apps/kdeprint/
share/apps/kdeprint/apsdriver1
share/apps/kdeprint/apsdriver2
share/apps/kdeprint/cups_logo.png
share/apps/kdeprint/cupsd.conf.template
share/apps/kdeprint/filters/
share/apps/kdeprint/filters/enscript.desktop
share/apps/kdeprint/filters/enscript.xml
@ -1312,7 +1331,6 @@ share/apps/kdeprint/icons/crystalsvg/64x64/
share/apps/kdeprint/icons/crystalsvg/64x64/apps/
share/apps/kdeprint/icons/crystalsvg/64x64/apps/kdeprint_printer.png
share/apps/kdeprint/icons/crystalsvg/64x64/apps/kdeprint_printer_class.png
share/apps/kdeprint/kde_logo.png
share/apps/kdeprint/lprngtooldriver1
share/apps/kdeprint/pics/
share/apps/kdeprint/pics/kdeprint_collate.png
@ -1334,13 +1352,10 @@ share/apps/kdeprint/pics/kdeprint_revportrait.png
share/apps/kdeprint/pics/kdeprint_uncollate.png
share/apps/kdeprint/pics/kdeprint_uncollate_reverse.png
share/apps/kdeprint/plugins/
share/apps/kdeprint/plugins/cups.print
share/apps/kdeprint/plugins/ext.print
share/apps/kdeprint/plugins/lpdunix.print
share/apps/kdeprint/plugins/lpr.print
share/apps/kdeprint/plugins/rlpr.print
share/apps/kdeprint/preview-mini.png
share/apps/kdeprint/preview.png
share/apps/kdeprint/side.png
share/apps/kdeprint/specials.desktop
share/apps/kdeprint/testprint.ps
@ -1440,10 +1455,6 @@ share/apps/khtml/icons/crystalsvg/16x16/actions/wallet_open.png
share/apps/khtml/icons/crystalsvg/22x22/
share/apps/khtml/icons/crystalsvg/22x22/actions/
share/apps/khtml/icons/crystalsvg/22x22/actions/bug.png
share/apps/khtml/icons/crystalsvg/22x22/actions/dbgnext.png
share/apps/khtml/icons/crystalsvg/22x22/actions/dbgrun.png
share/apps/khtml/icons/crystalsvg/22x22/actions/dbgrunto.png
share/apps/khtml/icons/crystalsvg/22x22/actions/dbgstep.png
share/apps/khtml/icons/crystalsvg/22x22/actions/images_display.png
share/apps/khtml/icons/crystalsvg/32x32/
share/apps/khtml/icons/crystalsvg/32x32/actions/
@ -1465,6 +1476,11 @@ share/apps/kio_uiserver/icons/crystalsvg/16x16/
share/apps/kio_uiserver/icons/crystalsvg/16x16/apps/
share/apps/kio_uiserver/icons/crystalsvg/16x16/apps/kio_uiserver.png
share/apps/kjava/
share/apps/kjava/icons/
share/apps/kjava/icons/crystalsvg/
share/apps/kjava/icons/crystalsvg/16x16/
share/apps/kjava/icons/crystalsvg/16x16/actions/
share/apps/kjava/icons/crystalsvg/16x16/actions/java.png
share/apps/kjava/kjava.jar
share/apps/kjava/kjava.policy
share/apps/kjava/pluginsinfo
@ -2132,6 +2148,7 @@ share/apps/ksgmltools2/customization/sv/entities/underArtisticLicense.docbook
share/apps/ksgmltools2/customization/sv/entities/underBSDLicense.docbook
share/apps/ksgmltools2/customization/sv/entities/underFDL.docbook
share/apps/ksgmltools2/customization/sv/entities/underGPL.docbook
share/apps/ksgmltools2/customization/sv/entities/underLGPL.docbook
share/apps/ksgmltools2/customization/sv/entities/underX11License.docbook
share/apps/ksgmltools2/customization/sv/entities/update-doc.docbook
share/apps/ksgmltools2/customization/sv/lang.entities
@ -3045,9 +3062,11 @@ share/autostart/
share/autostart/kab2kabc.desktop
share/config/
share/config/colors/
share/config/colors/40 Colors
share/config/colors/Royal
share/config/colors/Web
share/config/colors/40.colors
share/config/colors/Rainbow.colors
share/config/colors/Royal.colors
share/config/colors/Web.colors
share/config/ipv6blacklist
share/config/katefiletyperc
share/config/katesyntaxhighlightingrc
share/config/kdebug.areas
@ -3087,8 +3106,10 @@ share/doc/HTML/en/common/doctop1a.png
share/doc/HTML/en/common/doctop1b.png
share/doc/HTML/en/common/doctop2.png
share/doc/HTML/en/common/doxygen.css
share/doc/HTML/en/common/favicon.ico
share/doc/HTML/en/common/fdl-license
share/doc/HTML/en/common/fdl-license.html
share/doc/HTML/en/common/fdl-notice.html
share/doc/HTML/en/common/footer.html
share/doc/HTML/en/common/gpl-license
share/doc/HTML/en/common/gpl-license.html
@ -3099,6 +3120,7 @@ share/doc/HTML/en/common/kde-common.css
share/doc/HTML/en/common/kde-default.css
share/doc/HTML/en/common/kde-localised.css.template
share/doc/HTML/en/common/kde-web.css
share/doc/HTML/en/common/kde_gear_64.png
share/doc/HTML/en/common/kde_logo.png
share/doc/HTML/en/common/kde_logo_bg.png
share/doc/HTML/en/common/kmenu.png
@ -3118,31 +3140,67 @@ share/doc/HTML/en/common/xml.dcl
share/doc/HTML/en/kdelibs-apidocs/
share/doc/HTML/en/kdelibs-apidocs/arts/
share/doc/HTML/en/kdelibs-apidocs/arts/html/
share/doc/HTML/en/kdelibs-apidocs/common
share/doc/HTML/en/kdelibs-apidocs/dcop/
share/doc/HTML/en/kdelibs-apidocs/dcop/html/
share/doc/HTML/en/kdelibs-apidocs/dnssd/
share/doc/HTML/en/kdelibs-apidocs/dnssd/html/
share/doc/HTML/en/kdelibs-apidocs/interfaces/
share/doc/HTML/en/kdelibs-apidocs/interfaces/html/
share/doc/HTML/en/kdelibs-apidocs/interfaces/kimproxy/
share/doc/HTML/en/kdelibs-apidocs/interfaces/kimproxy/interface/
share/doc/HTML/en/kdelibs-apidocs/interfaces/kimproxy/interface/html/
share/doc/HTML/en/kdelibs-apidocs/interfaces/kimproxy/library/
share/doc/HTML/en/kdelibs-apidocs/interfaces/kimproxy/library/html/
share/doc/HTML/en/kdelibs-apidocs/interfaces/kspeech/
share/doc/HTML/en/kdelibs-apidocs/interfaces/kspeech/html/
share/doc/HTML/en/kdelibs-apidocs/interfaces/ktexteditor/
share/doc/HTML/en/kdelibs-apidocs/interfaces/ktexteditor/html/
share/doc/HTML/en/kdelibs-apidocs/kabc/
share/doc/HTML/en/kdelibs-apidocs/kabc/html/
share/doc/HTML/en/kdelibs-apidocs/kate/
share/doc/HTML/en/kdelibs-apidocs/kate/html/
share/doc/HTML/en/kdelibs-apidocs/kcmshell/
share/doc/HTML/en/kdelibs-apidocs/kcmshell/html/
share/doc/HTML/en/kdelibs-apidocs/kdecore/
share/doc/HTML/en/kdelibs-apidocs/kdecore/html/
share/doc/HTML/en/kdelibs-apidocs/kded/
share/doc/HTML/en/kdelibs-apidocs/kded/html/
share/doc/HTML/en/kdelibs-apidocs/kdefx/
share/doc/HTML/en/kdelibs-apidocs/kdefx/html/
share/doc/HTML/en/kdelibs-apidocs/kdeprint/
share/doc/HTML/en/kdelibs-apidocs/kdeprint/html/
share/doc/HTML/en/kdelibs-apidocs/kdesu/
share/doc/HTML/en/kdelibs-apidocs/kdesu/html/
share/doc/HTML/en/kdelibs-apidocs/kdeui/
share/doc/HTML/en/kdelibs-apidocs/kdeui/html/
share/doc/HTML/en/kdelibs-apidocs/kdoctools/
share/doc/HTML/en/kdelibs-apidocs/kdoctools/html/
share/doc/HTML/en/kdelibs-apidocs/khtml/
share/doc/HTML/en/kdelibs-apidocs/khtml/html/
share/doc/HTML/en/kdelibs-apidocs/kimgio/
share/doc/HTML/en/kdelibs-apidocs/kimgio/html/
share/doc/HTML/en/kdelibs-apidocs/kinit/
share/doc/HTML/en/kdelibs-apidocs/kinit/html/
share/doc/HTML/en/kdelibs-apidocs/kio/
share/doc/HTML/en/kdelibs-apidocs/kio/bookmarks/
share/doc/HTML/en/kdelibs-apidocs/kio/bookmarks/html/
share/doc/HTML/en/kdelibs-apidocs/kio/html/
share/doc/HTML/en/kdelibs-apidocs/kio/httpfilter/
share/doc/HTML/en/kdelibs-apidocs/kio/httpfilter/html/
share/doc/HTML/en/kdelibs-apidocs/kio/kfile/
share/doc/HTML/en/kdelibs-apidocs/kio/kfile/html/
share/doc/HTML/en/kdelibs-apidocs/kio/kio/
share/doc/HTML/en/kdelibs-apidocs/kio/kio/html/
share/doc/HTML/en/kdelibs-apidocs/kio/kioexec/
share/doc/HTML/en/kdelibs-apidocs/kio/kioexec/html/
share/doc/HTML/en/kdelibs-apidocs/kio/kpasswdserver/
share/doc/HTML/en/kdelibs-apidocs/kio/kpasswdserver/html/
share/doc/HTML/en/kdelibs-apidocs/kio/kssl/
share/doc/HTML/en/kdelibs-apidocs/kio/kssl/html/
share/doc/HTML/en/kdelibs-apidocs/kioslave/
share/doc/HTML/en/kdelibs-apidocs/kioslave/html/
share/doc/HTML/en/kdelibs-apidocs/kioslave/http/
share/doc/HTML/en/kdelibs-apidocs/kioslave/http/html/
share/doc/HTML/en/kdelibs-apidocs/kjs/
share/doc/HTML/en/kdelibs-apidocs/kjs/html/
share/doc/HTML/en/kdelibs-apidocs/kmdi/
@ -3155,12 +3213,18 @@ share/doc/HTML/en/kdelibs-apidocs/kparts/
share/doc/HTML/en/kdelibs-apidocs/kparts/html/
share/doc/HTML/en/kdelibs-apidocs/kresources/
share/doc/HTML/en/kdelibs-apidocs/kresources/html/
share/doc/HTML/en/kdelibs-apidocs/kspell2/
share/doc/HTML/en/kdelibs-apidocs/kspell2/html/
share/doc/HTML/en/kdelibs-apidocs/kunittest/
share/doc/HTML/en/kdelibs-apidocs/kunittest/html/
share/doc/HTML/en/kdelibs-apidocs/kutils/
share/doc/HTML/en/kdelibs-apidocs/kutils/html/
share/doc/HTML/en/kdelibs-apidocs/kwallet/
share/doc/HTML/en/kdelibs-apidocs/kwallet/html/
share/doc/HTML/en/kdelibs-apidocs/libkmid/
share/doc/HTML/en/kdelibs-apidocs/libkmid/html/
share/doc/HTML/en/kdelibs-apidocs/libkscreensaver/
share/doc/HTML/en/kdelibs-apidocs/libkscreensaver/html/
share/doc/HTML/en/kspell/
share/doc/HTML/en/kspell/common
share/doc/HTML/en/kspell/index.cache.bz2
@ -3213,13 +3277,11 @@ share/icons/
share/icons/crystalsvg/
share/icons/crystalsvg/128x128/
share/icons/crystalsvg/128x128/actions/
share/icons/crystalsvg/128x128/actions/contents2.png
share/icons/crystalsvg/128x128/actions/fileprint.png
share/icons/crystalsvg/128x128/actions/filequickprint.png
share/icons/crystalsvg/128x128/actions/frameprint.png
share/icons/crystalsvg/128x128/actions/player_playlist.png
share/icons/crystalsvg/128x128/actions/launch.png
share/icons/crystalsvg/128x128/actions/share.png
share/icons/crystalsvg/128x128/apps/
share/icons/crystalsvg/128x128/apps/kmenu.png
share/icons/crystalsvg/128x128/apps/kttsd.png
share/icons/crystalsvg/128x128/apps/password.png
share/icons/crystalsvg/128x128/devices/
share/icons/crystalsvg/128x128/devices/blockdevice.png
@ -3230,6 +3292,8 @@ share/icons/crystalsvg/128x128/devices/compact_flash_mount.png
share/icons/crystalsvg/128x128/devices/compact_flash_unmount.png
share/icons/crystalsvg/128x128/devices/hdd_mount.png
share/icons/crystalsvg/128x128/devices/hdd_unmount.png
share/icons/crystalsvg/128x128/devices/ipod_mount.png
share/icons/crystalsvg/128x128/devices/ipod_unmount.png
share/icons/crystalsvg/128x128/devices/memory_stick_mount.png
share/icons/crystalsvg/128x128/devices/memory_stick_unmount.png
share/icons/crystalsvg/128x128/devices/mouse.png
@ -3274,14 +3338,15 @@ share/icons/crystalsvg/128x128/filesystems/folder_violet.png
share/icons/crystalsvg/128x128/filesystems/folder_violet_open.png
share/icons/crystalsvg/128x128/filesystems/folder_yellow.png
share/icons/crystalsvg/128x128/filesystems/folder_yellow_open.png
share/icons/crystalsvg/128x128/filesystems/lockoverlay.png
share/icons/crystalsvg/128x128/filesystems/link_overlay.png
share/icons/crystalsvg/128x128/filesystems/lock_overlay.png
share/icons/crystalsvg/128x128/filesystems/network.png
share/icons/crystalsvg/128x128/filesystems/network_local.png
share/icons/crystalsvg/128x128/filesystems/pipe.png
share/icons/crystalsvg/128x128/filesystems/trashcan_empty.png
share/icons/crystalsvg/128x128/filesystems/trashcan_full.png
share/icons/crystalsvg/128x128/filesystems/www.png
share/icons/crystalsvg/128x128/filesystems/zip.png
share/icons/crystalsvg/128x128/filesystems/zip_overlay.png
share/icons/crystalsvg/128x128/mimetypes/
share/icons/crystalsvg/128x128/mimetypes/applix.png
share/icons/crystalsvg/128x128/mimetypes/ascii.png
@ -3373,6 +3438,7 @@ share/icons/crystalsvg/16x16/actions/2leftarrow.png
share/icons/crystalsvg/16x16/actions/2rightarrow.png
share/icons/crystalsvg/16x16/actions/2uparrow.png
share/icons/crystalsvg/16x16/actions/about_kde.png
share/icons/crystalsvg/16x16/actions/add.png
share/icons/crystalsvg/16x16/actions/airbrush.png
share/icons/crystalsvg/16x16/actions/apply.png
share/icons/crystalsvg/16x16/actions/attach.png
@ -3457,6 +3523,7 @@ share/icons/crystalsvg/16x16/actions/identity.png
share/icons/crystalsvg/16x16/actions/info.png
share/icons/crystalsvg/16x16/actions/inline_image.png
share/icons/crystalsvg/16x16/actions/inline_table.png
share/icons/crystalsvg/16x16/actions/kde.png
share/icons/crystalsvg/16x16/actions/kde1.png
share/icons/crystalsvg/16x16/actions/kde3.png
share/icons/crystalsvg/16x16/actions/kde4.png
@ -3547,11 +3614,13 @@ share/icons/crystalsvg/16x16/actions/run.png
share/icons/crystalsvg/16x16/actions/save_all.png
share/icons/crystalsvg/16x16/actions/services.png
share/icons/crystalsvg/16x16/actions/share.png
share/icons/crystalsvg/16x16/actions/show_side_panel.png
share/icons/crystalsvg/16x16/actions/signature.png
share/icons/crystalsvg/16x16/actions/spellcheck.png
share/icons/crystalsvg/16x16/actions/stamp.png
share/icons/crystalsvg/16x16/actions/start.png
share/icons/crystalsvg/16x16/actions/stop.png
share/icons/crystalsvg/16x16/actions/switchuser.png
share/icons/crystalsvg/16x16/actions/tab_breakoff.png
share/icons/crystalsvg/16x16/actions/tab_duplicate.png
share/icons/crystalsvg/16x16/actions/tab_new.png
@ -3579,6 +3648,9 @@ share/icons/crystalsvg/16x16/actions/up.png
share/icons/crystalsvg/16x16/actions/view_bottom.png
share/icons/crystalsvg/16x16/actions/view_choose.png
share/icons/crystalsvg/16x16/actions/view_detailed.png
share/icons/crystalsvg/16x16/actions/view_fit_height.png
share/icons/crystalsvg/16x16/actions/view_fit_width.png
share/icons/crystalsvg/16x16/actions/view_fit_window.png
share/icons/crystalsvg/16x16/actions/view_icon.png
share/icons/crystalsvg/16x16/actions/view_left_right.png
share/icons/crystalsvg/16x16/actions/view_multicolumn.png
@ -3599,6 +3671,8 @@ share/icons/crystalsvg/16x16/actions/window_nofullscreen.png
share/icons/crystalsvg/16x16/actions/window_suppressed.png
share/icons/crystalsvg/16x16/actions/wizard.png
share/icons/crystalsvg/16x16/apps/
share/icons/crystalsvg/16x16/apps/kmenu.png
share/icons/crystalsvg/16x16/apps/kttsd.png
share/icons/crystalsvg/16x16/apps/password.png
share/icons/crystalsvg/16x16/devices/
share/icons/crystalsvg/16x16/devices/3floppy_mount.png
@ -3621,6 +3695,8 @@ share/icons/crystalsvg/16x16/devices/dvd_mount.png
share/icons/crystalsvg/16x16/devices/dvd_unmount.png
share/icons/crystalsvg/16x16/devices/hdd_mount.png
share/icons/crystalsvg/16x16/devices/hdd_unmount.png
share/icons/crystalsvg/16x16/devices/ipod_mount.png
share/icons/crystalsvg/16x16/devices/ipod_unmount.png
share/icons/crystalsvg/16x16/devices/joystick.png
share/icons/crystalsvg/16x16/devices/memory.png
share/icons/crystalsvg/16x16/devices/memory_stick_mount.png
@ -3682,8 +3758,8 @@ share/icons/crystalsvg/16x16/filesystems/folder_violet_open.png
share/icons/crystalsvg/16x16/filesystems/folder_yellow.png
share/icons/crystalsvg/16x16/filesystems/folder_yellow_open.png
share/icons/crystalsvg/16x16/filesystems/ftp.png
share/icons/crystalsvg/16x16/filesystems/link.png
share/icons/crystalsvg/16x16/filesystems/lockoverlay.png
share/icons/crystalsvg/16x16/filesystems/link_overlay.png
share/icons/crystalsvg/16x16/filesystems/lock_overlay.png
share/icons/crystalsvg/16x16/filesystems/network.png
share/icons/crystalsvg/16x16/filesystems/network_local.png
share/icons/crystalsvg/16x16/filesystems/pipe.png
@ -3691,7 +3767,7 @@ share/icons/crystalsvg/16x16/filesystems/server.png
share/icons/crystalsvg/16x16/filesystems/trashcan_empty.png
share/icons/crystalsvg/16x16/filesystems/trashcan_full.png
share/icons/crystalsvg/16x16/filesystems/www.png
share/icons/crystalsvg/16x16/filesystems/zip.png
share/icons/crystalsvg/16x16/filesystems/zip_overlay.png
share/icons/crystalsvg/16x16/mimetypes/
share/icons/crystalsvg/16x16/mimetypes/applix.png
share/icons/crystalsvg/16x16/mimetypes/ascii.png
@ -3787,6 +3863,7 @@ share/icons/crystalsvg/22x22/actions/2leftarrow.png
share/icons/crystalsvg/22x22/actions/2rightarrow.png
share/icons/crystalsvg/22x22/actions/2uparrow.png
share/icons/crystalsvg/22x22/actions/about_kde.png
share/icons/crystalsvg/22x22/actions/add.png
share/icons/crystalsvg/22x22/actions/airbrush.png
share/icons/crystalsvg/22x22/actions/apply.png
share/icons/crystalsvg/22x22/actions/attach.png
@ -3816,6 +3893,10 @@ share/icons/crystalsvg/22x22/actions/contents.png
share/icons/crystalsvg/22x22/actions/contents2.png
share/icons/crystalsvg/22x22/actions/contexthelp.png
share/icons/crystalsvg/22x22/actions/crop.png
share/icons/crystalsvg/22x22/actions/dbgnext.png
share/icons/crystalsvg/22x22/actions/dbgrun.png
share/icons/crystalsvg/22x22/actions/dbgrunto.png
share/icons/crystalsvg/22x22/actions/dbgstep.png
share/icons/crystalsvg/22x22/actions/decrypted.png
share/icons/crystalsvg/22x22/actions/down.png
share/icons/crystalsvg/22x22/actions/edit.png
@ -3869,7 +3950,6 @@ share/icons/crystalsvg/22x22/actions/idea.png
share/icons/crystalsvg/22x22/actions/identity.png
share/icons/crystalsvg/22x22/actions/inline_image.png
share/icons/crystalsvg/22x22/actions/inline_table.png
share/icons/crystalsvg/22x22/actions/kde/
share/icons/crystalsvg/22x22/actions/kde.png
share/icons/crystalsvg/22x22/actions/key_enter.png
share/icons/crystalsvg/22x22/actions/launch.png
@ -3945,6 +4025,7 @@ share/icons/crystalsvg/22x22/actions/reload.png
share/icons/crystalsvg/22x22/actions/reload3.png
share/icons/crystalsvg/22x22/actions/reload_all_tabs.png
share/icons/crystalsvg/22x22/actions/reload_page.png
share/icons/crystalsvg/22x22/actions/remove.png
share/icons/crystalsvg/22x22/actions/revert.png
share/icons/crystalsvg/22x22/actions/rightjust.png
share/icons/crystalsvg/22x22/actions/rotate.png
@ -3953,11 +4034,13 @@ share/icons/crystalsvg/22x22/actions/rotate_cw.png
share/icons/crystalsvg/22x22/actions/run.png
share/icons/crystalsvg/22x22/actions/save_all.png
share/icons/crystalsvg/22x22/actions/share.png
share/icons/crystalsvg/22x22/actions/show_side_panel.png
share/icons/crystalsvg/22x22/actions/showmenu.png
share/icons/crystalsvg/22x22/actions/signature.png
share/icons/crystalsvg/22x22/actions/spellcheck.png
share/icons/crystalsvg/22x22/actions/start.png
share/icons/crystalsvg/22x22/actions/stop.png
share/icons/crystalsvg/22x22/actions/switchuser.png
share/icons/crystalsvg/22x22/actions/text.png
share/icons/crystalsvg/22x22/actions/text_block.png
share/icons/crystalsvg/22x22/actions/text_bold.png
@ -3980,6 +4063,9 @@ share/icons/crystalsvg/22x22/actions/up.png
share/icons/crystalsvg/22x22/actions/view_bottom.png
share/icons/crystalsvg/22x22/actions/view_choose.png
share/icons/crystalsvg/22x22/actions/view_detailed.png
share/icons/crystalsvg/22x22/actions/view_fit_height.png
share/icons/crystalsvg/22x22/actions/view_fit_width.png
share/icons/crystalsvg/22x22/actions/view_fit_window.png
share/icons/crystalsvg/22x22/actions/view_icon.png
share/icons/crystalsvg/22x22/actions/view_left_right.png
share/icons/crystalsvg/22x22/actions/view_multicolumn.png
@ -3999,6 +4085,8 @@ share/icons/crystalsvg/22x22/actions/window_new.png
share/icons/crystalsvg/22x22/actions/window_nofullscreen.png
share/icons/crystalsvg/22x22/actions/wizard.png
share/icons/crystalsvg/22x22/apps/
share/icons/crystalsvg/22x22/apps/kmenu.png
share/icons/crystalsvg/22x22/apps/kttsd.png
share/icons/crystalsvg/22x22/apps/password.png
share/icons/crystalsvg/22x22/devices/
share/icons/crystalsvg/22x22/devices/3floppy_mount.png
@ -4010,6 +4098,8 @@ share/icons/crystalsvg/22x22/devices/compact_flash_mount.png
share/icons/crystalsvg/22x22/devices/compact_flash_unmount.png
share/icons/crystalsvg/22x22/devices/hdd_mount.png
share/icons/crystalsvg/22x22/devices/hdd_unmount.png
share/icons/crystalsvg/22x22/devices/ipod_mount.png
share/icons/crystalsvg/22x22/devices/ipod_unmount.png
share/icons/crystalsvg/22x22/devices/joystick.png
share/icons/crystalsvg/22x22/devices/memory_stick_mount.png
share/icons/crystalsvg/22x22/devices/memory_stick_unmount.png
@ -4040,10 +4130,12 @@ share/icons/crystalsvg/22x22/filesystems/folder_violet.png
share/icons/crystalsvg/22x22/filesystems/folder_violet_open.png
share/icons/crystalsvg/22x22/filesystems/folder_yellow.png
share/icons/crystalsvg/22x22/filesystems/folder_yellow_open.png
share/icons/crystalsvg/22x22/filesystems/link_overlay.png
share/icons/crystalsvg/22x22/filesystems/network.png
share/icons/crystalsvg/22x22/filesystems/trashcan_empty.png
share/icons/crystalsvg/22x22/filesystems/trashcan_full.png
share/icons/crystalsvg/22x22/filesystems/www.png
share/icons/crystalsvg/22x22/filesystems/zip_overlay.png
share/icons/crystalsvg/22x22/mimetypes/
share/icons/crystalsvg/22x22/mimetypes/applix.png
share/icons/crystalsvg/22x22/mimetypes/ascii.png
@ -4132,6 +4224,7 @@ share/icons/crystalsvg/22x22/mimetypes/zip.png
share/icons/crystalsvg/32x32/
share/icons/crystalsvg/32x32/actions/
share/icons/crystalsvg/32x32/actions/about_kde.png
share/icons/crystalsvg/32x32/actions/add.png
share/icons/crystalsvg/32x32/actions/apply.png
share/icons/crystalsvg/32x32/actions/attach.png
share/icons/crystalsvg/32x32/actions/back.png
@ -4148,6 +4241,7 @@ share/icons/crystalsvg/32x32/actions/centrejust.png
share/icons/crystalsvg/32x32/actions/charset.png
share/icons/crystalsvg/32x32/actions/clear_left.png
share/icons/crystalsvg/32x32/actions/colorize.png
share/icons/crystalsvg/32x32/actions/colorpicker.png
share/icons/crystalsvg/32x32/actions/compfile.png
share/icons/crystalsvg/32x32/actions/configure.png
share/icons/crystalsvg/32x32/actions/connect_creating.png
@ -4168,6 +4262,7 @@ share/icons/crystalsvg/32x32/actions/editshred.png
share/icons/crystalsvg/32x32/actions/edittrash.png
share/icons/crystalsvg/32x32/actions/emptytrash.png
share/icons/crystalsvg/32x32/actions/encrypted.png
share/icons/crystalsvg/32x32/actions/eraser.png
share/icons/crystalsvg/32x32/actions/exec.png
share/icons/crystalsvg/32x32/actions/exit.png
share/icons/crystalsvg/32x32/actions/fileclose.png
@ -4193,10 +4288,10 @@ share/icons/crystalsvg/32x32/actions/halfencrypted.png
share/icons/crystalsvg/32x32/actions/help.png
share/icons/crystalsvg/32x32/actions/identity.png
share/icons/crystalsvg/32x32/actions/indent.png
share/icons/crystalsvg/32x32/actions/kde/
share/icons/crystalsvg/32x32/actions/kde.png
share/icons/crystalsvg/32x32/actions/kdevelop_down.png
share/icons/crystalsvg/32x32/actions/knewstuff.png
share/icons/crystalsvg/32x32/actions/launch.png
share/icons/crystalsvg/32x32/actions/leftjust.png
share/icons/crystalsvg/32x32/actions/locationbar_erase.png
share/icons/crystalsvg/32x32/actions/lock.png
@ -4267,6 +4362,7 @@ share/icons/crystalsvg/32x32/actions/redo.png
share/icons/crystalsvg/32x32/actions/reload.png
share/icons/crystalsvg/32x32/actions/reload_all_tabs.png
share/icons/crystalsvg/32x32/actions/reload_page.png
share/icons/crystalsvg/32x32/actions/remove.png
share/icons/crystalsvg/32x32/actions/revert.png
share/icons/crystalsvg/32x32/actions/rightjust.png
share/icons/crystalsvg/32x32/actions/rotate.png
@ -4275,10 +4371,12 @@ share/icons/crystalsvg/32x32/actions/rotate_cw.png
share/icons/crystalsvg/32x32/actions/run.png
share/icons/crystalsvg/32x32/actions/save_all.png
share/icons/crystalsvg/32x32/actions/share.png
share/icons/crystalsvg/32x32/actions/show_side_panel.png
share/icons/crystalsvg/32x32/actions/signature.png
share/icons/crystalsvg/32x32/actions/spellcheck.png
share/icons/crystalsvg/32x32/actions/start.png
share/icons/crystalsvg/32x32/actions/stop.png
share/icons/crystalsvg/32x32/actions/switchuser.png
share/icons/crystalsvg/32x32/actions/text_block.png
share/icons/crystalsvg/32x32/actions/text_bold.png
share/icons/crystalsvg/32x32/actions/text_center.png
@ -4299,6 +4397,9 @@ share/icons/crystalsvg/32x32/actions/up.png
share/icons/crystalsvg/32x32/actions/view_bottom.png
share/icons/crystalsvg/32x32/actions/view_choose.png
share/icons/crystalsvg/32x32/actions/view_detailed.png
share/icons/crystalsvg/32x32/actions/view_fit_height.png
share/icons/crystalsvg/32x32/actions/view_fit_width.png
share/icons/crystalsvg/32x32/actions/view_fit_window.png
share/icons/crystalsvg/32x32/actions/view_icon.png
share/icons/crystalsvg/32x32/actions/view_left_right.png
share/icons/crystalsvg/32x32/actions/view_multicolumn.png
@ -4318,6 +4419,8 @@ share/icons/crystalsvg/32x32/actions/window_new.png
share/icons/crystalsvg/32x32/actions/window_nofullscreen.png
share/icons/crystalsvg/32x32/actions/wizard.png
share/icons/crystalsvg/32x32/apps/
share/icons/crystalsvg/32x32/apps/kmenu.png
share/icons/crystalsvg/32x32/apps/kttsd.png
share/icons/crystalsvg/32x32/apps/password.png
share/icons/crystalsvg/32x32/devices/
share/icons/crystalsvg/32x32/devices/3floppy_mount.png
@ -4340,6 +4443,8 @@ share/icons/crystalsvg/32x32/devices/dvd_mount.png
share/icons/crystalsvg/32x32/devices/dvd_unmount.png
share/icons/crystalsvg/32x32/devices/hdd_mount.png
share/icons/crystalsvg/32x32/devices/hdd_unmount.png
share/icons/crystalsvg/32x32/devices/ipod_mount.png
share/icons/crystalsvg/32x32/devices/ipod_unmount.png
share/icons/crystalsvg/32x32/devices/joystick.png
share/icons/crystalsvg/32x32/devices/memory.png
share/icons/crystalsvg/32x32/devices/memory_stick_mount.png
@ -4398,15 +4503,15 @@ share/icons/crystalsvg/32x32/filesystems/folder_violet_open.png
share/icons/crystalsvg/32x32/filesystems/folder_yellow.png
share/icons/crystalsvg/32x32/filesystems/folder_yellow_open.png
share/icons/crystalsvg/32x32/filesystems/ftp.png
share/icons/crystalsvg/32x32/filesystems/link.png
share/icons/crystalsvg/32x32/filesystems/lockoverlay.png
share/icons/crystalsvg/32x32/filesystems/link_overlay.png
share/icons/crystalsvg/32x32/filesystems/lock_overlay.png
share/icons/crystalsvg/32x32/filesystems/network.png
share/icons/crystalsvg/32x32/filesystems/network_local.png
share/icons/crystalsvg/32x32/filesystems/pipe.png
share/icons/crystalsvg/32x32/filesystems/trashcan_empty.png
share/icons/crystalsvg/32x32/filesystems/trashcan_full.png
share/icons/crystalsvg/32x32/filesystems/www.png
share/icons/crystalsvg/32x32/filesystems/zip.png
share/icons/crystalsvg/32x32/filesystems/zip_overlay.png
share/icons/crystalsvg/32x32/mimetypes/
share/icons/crystalsvg/32x32/mimetypes/applix.png
share/icons/crystalsvg/32x32/mimetypes/ascii.png
@ -4493,12 +4598,16 @@ share/icons/crystalsvg/32x32/mimetypes/vectorgfx.png
share/icons/crystalsvg/32x32/mimetypes/video.png
share/icons/crystalsvg/32x32/mimetypes/widget_doc.png
share/icons/crystalsvg/32x32/mimetypes/wordprocessing.png
share/icons/crystalsvg/32x32/mimetypes/zip.png
share/icons/crystalsvg/48x48/
share/icons/crystalsvg/48x48/actions/
share/icons/crystalsvg/48x48/actions/add.png
share/icons/crystalsvg/48x48/actions/back.png
share/icons/crystalsvg/48x48/actions/bookmark.png
share/icons/crystalsvg/48x48/actions/colorpicker.png
share/icons/crystalsvg/48x48/actions/contents2.png
share/icons/crystalsvg/48x48/actions/down.png
share/icons/crystalsvg/48x48/actions/eraser.png
share/icons/crystalsvg/48x48/actions/exit.png
share/icons/crystalsvg/48x48/actions/fileclose.png
share/icons/crystalsvg/48x48/actions/filenew.png
@ -4507,8 +4616,11 @@ share/icons/crystalsvg/48x48/actions/filequickprint.png
share/icons/crystalsvg/48x48/actions/forward.png
share/icons/crystalsvg/48x48/actions/frameprint.png
share/icons/crystalsvg/48x48/actions/gear.png
share/icons/crystalsvg/48x48/actions/gohome.png
share/icons/crystalsvg/48x48/actions/identity.png
share/icons/crystalsvg/48x48/actions/indent.png
share/icons/crystalsvg/48x48/actions/kde.png
share/icons/crystalsvg/48x48/actions/launch.png
share/icons/crystalsvg/48x48/actions/lock.png
share/icons/crystalsvg/48x48/actions/mail_new.png
share/icons/crystalsvg/48x48/actions/mail_post_to.png
@ -4517,11 +4629,22 @@ share/icons/crystalsvg/48x48/actions/player_playlist.png
share/icons/crystalsvg/48x48/actions/presence_away.png
share/icons/crystalsvg/48x48/actions/presence_offline.png
share/icons/crystalsvg/48x48/actions/presence_online.png
share/icons/crystalsvg/48x48/actions/reload.png
share/icons/crystalsvg/48x48/actions/reload_all_tabs.png
share/icons/crystalsvg/48x48/actions/reload_page.png
share/icons/crystalsvg/48x48/actions/remove.png
share/icons/crystalsvg/48x48/actions/rotate.png
share/icons/crystalsvg/48x48/actions/rotate_ccw.png
share/icons/crystalsvg/48x48/actions/rotate_cw.png
share/icons/crystalsvg/48x48/actions/share.png
share/icons/crystalsvg/48x48/actions/stop.png
share/icons/crystalsvg/48x48/actions/switchuser.png
share/icons/crystalsvg/48x48/actions/unindent.png
share/icons/crystalsvg/48x48/actions/up.png
share/icons/crystalsvg/48x48/actions/wizard.png
share/icons/crystalsvg/48x48/apps/
share/icons/crystalsvg/48x48/apps/kmenu.png
share/icons/crystalsvg/48x48/apps/kttsd.png
share/icons/crystalsvg/48x48/apps/password.png
share/icons/crystalsvg/48x48/devices/
share/icons/crystalsvg/48x48/devices/3floppy_mount.png
@ -4544,6 +4667,8 @@ share/icons/crystalsvg/48x48/devices/dvd_mount.png
share/icons/crystalsvg/48x48/devices/dvd_unmount.png
share/icons/crystalsvg/48x48/devices/hdd_mount.png
share/icons/crystalsvg/48x48/devices/hdd_unmount.png
share/icons/crystalsvg/48x48/devices/ipod_mount.png
share/icons/crystalsvg/48x48/devices/ipod_unmount.png
share/icons/crystalsvg/48x48/devices/joystick.png
share/icons/crystalsvg/48x48/devices/memory.png
share/icons/crystalsvg/48x48/devices/memory_stick_mount.png
@ -4604,8 +4729,8 @@ share/icons/crystalsvg/48x48/filesystems/folder_violet_open.png
share/icons/crystalsvg/48x48/filesystems/folder_yellow.png
share/icons/crystalsvg/48x48/filesystems/folder_yellow_open.png
share/icons/crystalsvg/48x48/filesystems/ftp.png
share/icons/crystalsvg/48x48/filesystems/link.png
share/icons/crystalsvg/48x48/filesystems/lockoverlay.png
share/icons/crystalsvg/48x48/filesystems/link_overlay.png
share/icons/crystalsvg/48x48/filesystems/lock_overlay.png
share/icons/crystalsvg/48x48/filesystems/network.png
share/icons/crystalsvg/48x48/filesystems/network_local.png
share/icons/crystalsvg/48x48/filesystems/pipe.png
@ -4613,7 +4738,7 @@ share/icons/crystalsvg/48x48/filesystems/server.png
share/icons/crystalsvg/48x48/filesystems/trashcan_empty.png
share/icons/crystalsvg/48x48/filesystems/trashcan_full.png
share/icons/crystalsvg/48x48/filesystems/www.png
share/icons/crystalsvg/48x48/filesystems/zip.png
share/icons/crystalsvg/48x48/filesystems/zip_overlay.png
share/icons/crystalsvg/48x48/mimetypes/
share/icons/crystalsvg/48x48/mimetypes/applix.png
share/icons/crystalsvg/48x48/mimetypes/ascii.png
@ -4704,16 +4829,13 @@ share/icons/crystalsvg/48x48/mimetypes/wordprocessing.png
share/icons/crystalsvg/48x48/mimetypes/zip.png
share/icons/crystalsvg/64x64/
share/icons/crystalsvg/64x64/actions/
share/icons/crystalsvg/64x64/actions/contents2.png
share/icons/crystalsvg/64x64/actions/favorites.png
share/icons/crystalsvg/64x64/actions/fileprint.png
share/icons/crystalsvg/64x64/actions/filequickprint.png
share/icons/crystalsvg/64x64/actions/frameprint.png
share/icons/crystalsvg/64x64/actions/knewstuff.png
share/icons/crystalsvg/64x64/actions/player_play.png
share/icons/crystalsvg/64x64/actions/player_playlist.png
share/icons/crystalsvg/64x64/actions/share.png
share/icons/crystalsvg/64x64/apps/
share/icons/crystalsvg/64x64/apps/kmenu.png
share/icons/crystalsvg/64x64/apps/kttsd.png
share/icons/crystalsvg/64x64/apps/password.png
share/icons/crystalsvg/64x64/devices/
share/icons/crystalsvg/64x64/devices/3floppy_mount.png
@ -4736,6 +4858,8 @@ share/icons/crystalsvg/64x64/devices/dvd_mount.png
share/icons/crystalsvg/64x64/devices/dvd_unmount.png
share/icons/crystalsvg/64x64/devices/hdd_mount.png
share/icons/crystalsvg/64x64/devices/hdd_unmount.png
share/icons/crystalsvg/64x64/devices/ipod_mount.png
share/icons/crystalsvg/64x64/devices/ipod_unmount.png
share/icons/crystalsvg/64x64/devices/joystick.png
share/icons/crystalsvg/64x64/devices/memory.png
share/icons/crystalsvg/64x64/devices/memory_stick_mount.png
@ -4793,14 +4917,15 @@ share/icons/crystalsvg/64x64/filesystems/folder_violet.png
share/icons/crystalsvg/64x64/filesystems/folder_violet_open.png
share/icons/crystalsvg/64x64/filesystems/folder_yellow.png
share/icons/crystalsvg/64x64/filesystems/folder_yellow_open.png
share/icons/crystalsvg/64x64/filesystems/lockoverlay.png
share/icons/crystalsvg/64x64/filesystems/link_overlay.png
share/icons/crystalsvg/64x64/filesystems/lock_overlay.png
share/icons/crystalsvg/64x64/filesystems/network.png
share/icons/crystalsvg/64x64/filesystems/network_local.png
share/icons/crystalsvg/64x64/filesystems/pipe.png
share/icons/crystalsvg/64x64/filesystems/trashcan_empty.png
share/icons/crystalsvg/64x64/filesystems/trashcan_full.png
share/icons/crystalsvg/64x64/filesystems/www.png
share/icons/crystalsvg/64x64/filesystems/zip.png
share/icons/crystalsvg/64x64/filesystems/zip_overlay.png
share/icons/crystalsvg/64x64/mimetypes/
share/icons/crystalsvg/64x64/mimetypes/applix.png
share/icons/crystalsvg/64x64/mimetypes/ascii.png
@ -4891,26 +5016,67 @@ share/icons/crystalsvg/index.theme
share/icons/crystalsvg/scalable/
share/icons/crystalsvg/scalable/actions/
share/icons/crystalsvg/scalable/actions/about_kde.svgz
share/icons/crystalsvg/scalable/actions/add.svgz
share/icons/crystalsvg/scalable/actions/back.svgz
share/icons/crystalsvg/scalable/actions/bottom.svgz
share/icons/crystalsvg/scalable/actions/colorpicker.svgz
share/icons/crystalsvg/scalable/actions/configure.svgz
share/icons/crystalsvg/scalable/actions/contents2.svgz
share/icons/crystalsvg/scalable/actions/down.svgz
share/icons/crystalsvg/scalable/actions/eraser.svgz
share/icons/crystalsvg/scalable/actions/exit.svgz
share/icons/crystalsvg/scalable/actions/fileclose.svgz
share/icons/crystalsvg/scalable/actions/filenew.svgz
share/icons/crystalsvg/scalable/actions/fileprint.svgz
share/icons/crystalsvg/scalable/actions/filequickprint.svgz
share/icons/crystalsvg/scalable/actions/finish.svgz
share/icons/crystalsvg/scalable/actions/forward.svgz
share/icons/crystalsvg/scalable/actions/frameprint.svgz
share/icons/crystalsvg/scalable/actions/gohome.svgz
share/icons/crystalsvg/scalable/actions/info.svgz
share/icons/crystalsvg/scalable/actions/launch.svgz
share/icons/crystalsvg/scalable/actions/lock.svgz
share/icons/crystalsvg/scalable/actions/mail_generic.svgz
share/icons/crystalsvg/scalable/actions/mail_get.svgz
share/icons/crystalsvg/scalable/actions/mail_new.svgz
share/icons/crystalsvg/scalable/actions/mail_post_to.svgz
share/icons/crystalsvg/scalable/actions/next.svgz
share/icons/crystalsvg/scalable/actions/player_eject.svgz
share/icons/crystalsvg/scalable/actions/player_fwd.svgz
share/icons/crystalsvg/scalable/actions/player_next.svgz
share/icons/crystalsvg/scalable/actions/player_pause.svgz
share/icons/crystalsvg/scalable/actions/player_play.svgz
share/icons/crystalsvg/scalable/actions/player_rew.svgz
share/icons/crystalsvg/scalable/actions/player_start.svgz
share/icons/crystalsvg/scalable/actions/player_stop.svgz
share/icons/crystalsvg/scalable/actions/previous.svgz
share/icons/crystalsvg/scalable/actions/reload.svgz
share/icons/crystalsvg/scalable/actions/reload_all_tabs.svgz
share/icons/crystalsvg/scalable/actions/reload_page.svgz
share/icons/crystalsvg/scalable/actions/remove.svgz
share/icons/crystalsvg/scalable/actions/rotate.svgz
share/icons/crystalsvg/scalable/actions/rotate_ccw.svgz
share/icons/crystalsvg/scalable/actions/rotate_cw.svgz
share/icons/crystalsvg/scalable/actions/share.svgz
share/icons/crystalsvg/scalable/actions/start.svgz
share/icons/crystalsvg/scalable/actions/stop.svgz
share/icons/crystalsvg/scalable/actions/switchuser.svgz
share/icons/crystalsvg/scalable/actions/text_bild.svgz
share/icons/crystalsvg/scalable/actions/text_bold.svg
share/icons/crystalsvg/scalable/actions/text_bold.svgz
share/icons/crystalsvg/scalable/actions/text_italic.svgz
share/icons/crystalsvg/scalable/actions/text_strike.svgz
share/icons/crystalsvg/scalable/actions/text_sub.svgz
share/icons/crystalsvg/scalable/actions/text_super.svgz
share/icons/crystalsvg/scalable/actions/text_under.svgz
share/icons/crystalsvg/scalable/actions/top.svgz
share/icons/crystalsvg/scalable/actions/up.svgz
share/icons/crystalsvg/scalable/actions/view_fit_height.svgz
share/icons/crystalsvg/scalable/actions/view_fit_width.svgz
share/icons/crystalsvg/scalable/actions/view_fit_window.svgz
share/icons/crystalsvg/scalable/actions/wizard.svgz
share/icons/crystalsvg/scalable/apps/
share/icons/crystalsvg/scalable/apps/kmenu.svgz
share/icons/crystalsvg/scalable/apps/kttsd.svgz
share/icons/crystalsvg/scalable/devices/
share/icons/crystalsvg/scalable/devices/3floppy_mount.svgz
share/icons/crystalsvg/scalable/devices/3floppy_unmount.svgz
@ -4932,6 +5098,8 @@ share/icons/crystalsvg/scalable/devices/dvd_mount.svgz
share/icons/crystalsvg/scalable/devices/dvd_unmount.svgz
share/icons/crystalsvg/scalable/devices/hdd_mount.svgz
share/icons/crystalsvg/scalable/devices/hdd_unmount.svgz
share/icons/crystalsvg/scalable/devices/ipod_mount.svgz
share/icons/crystalsvg/scalable/devices/ipod_unmount.svgz
share/icons/crystalsvg/scalable/devices/joystick.svgz
share/icons/crystalsvg/scalable/devices/memory.svgz
share/icons/crystalsvg/scalable/devices/memory_stick_mount.svgz
@ -4996,8 +5164,8 @@ share/icons/crystalsvg/scalable/filesystems/folder_yellow.svgz
share/icons/crystalsvg/scalable/filesystems/folder_yellow_open.svgz
share/icons/crystalsvg/scalable/filesystems/home_blue.svgz
share/icons/crystalsvg/scalable/filesystems/home_white.svgz
share/icons/crystalsvg/scalable/filesystems/link.svgz
share/icons/crystalsvg/scalable/filesystems/lockoverlay.svgz
share/icons/crystalsvg/scalable/filesystems/link_overlay.svgz
share/icons/crystalsvg/scalable/filesystems/lock_overlay.svgz
share/icons/crystalsvg/scalable/filesystems/network.svgz
share/icons/crystalsvg/scalable/filesystems/network_local.svgz
share/icons/crystalsvg/scalable/filesystems/pipe.svgz
@ -5006,7 +5174,7 @@ share/icons/crystalsvg/scalable/filesystems/temporary.svgz
share/icons/crystalsvg/scalable/filesystems/trashcan_empty.svgz
share/icons/crystalsvg/scalable/filesystems/trashcan_full.svgz
share/icons/crystalsvg/scalable/filesystems/www.svgz
share/icons/crystalsvg/scalable/filesystems/zip.svgz
share/icons/crystalsvg/scalable/filesystems/zip_overlay.svgz
share/icons/crystalsvg/scalable/mimetypes/
share/icons/crystalsvg/scalable/mimetypes/applix.svgz
share/icons/crystalsvg/scalable/mimetypes/ascii.svgz
@ -5088,21 +5256,6 @@ share/icons/crystalsvg/scalable/mimetypes/wordprocessing.svgz
share/icons/crystalsvg/scalable/mimetypes/zip.svgz
share/icons/default.kde
share/icons/hicolor/
share/icons/hicolor/16x16/
share/icons/hicolor/16x16/actions/
share/icons/hicolor/16x16/actions/show_side_panel.png
share/icons/hicolor/16x16/actions/view_fit_width.png
share/icons/hicolor/16x16/actions/view_fit_window.png
share/icons/hicolor/22x22/
share/icons/hicolor/22x22/actions/
share/icons/hicolor/22x22/actions/show_side_panel.png
share/icons/hicolor/22x22/actions/view_fit_width.png
share/icons/hicolor/22x22/actions/view_fit_window.png
share/icons/hicolor/32x32/
share/icons/hicolor/32x32/actions/
share/icons/hicolor/32x32/actions/show_side_panel.png
share/icons/hicolor/32x32/actions/view_fit_width.png
share/icons/hicolor/32x32/actions/view_fit_window.png
@comment share/icons/hicolor/index.theme
share/locale/all_languages
share/mimelnk/
@ -5110,6 +5263,8 @@ share/mimelnk/all/
share/mimelnk/all/all.desktop
share/mimelnk/all/allfiles.desktop
share/mimelnk/application/
share/mimelnk/application/chm.desktop
share/mimelnk/application/fits.desktop
share/mimelnk/application/illustrator.desktop
share/mimelnk/application/java.desktop
share/mimelnk/application/mathml+xml.desktop
@ -5154,6 +5309,7 @@ share/mimelnk/application/vnd.stardivision.impress.desktop
share/mimelnk/application/vnd.stardivision.math.desktop
share/mimelnk/application/vnd.stardivision.writer-global.desktop
share/mimelnk/application/vnd.stardivision.writer.desktop
share/mimelnk/application/vnd.sun.xml.base.desktop
share/mimelnk/application/vnd.sun.xml.calc.desktop
share/mimelnk/application/vnd.sun.xml.calc.template.desktop
share/mimelnk/application/vnd.sun.xml.draw.desktop
@ -5214,6 +5370,7 @@ share/mimelnk/application/x-ica.desktop
share/mimelnk/application/x-iso.desktop
share/mimelnk/application/x-jar.desktop
share/mimelnk/application/x-java-applet.desktop
share/mimelnk/application/x-java-jnlp-file.desktop
share/mimelnk/application/x-java.desktop
share/mimelnk/application/x-javascript.desktop
share/mimelnk/application/x-karbon.desktop
@ -5252,12 +5409,15 @@ share/mimelnk/application/x-pkcs12.desktop
share/mimelnk/application/x-python-bytecode.desktop
share/mimelnk/application/x-python.desktop
share/mimelnk/application/x-quattropro.desktop
share/mimelnk/application/x-rar-compressed.desktop
share/mimelnk/application/x-rar.desktop
share/mimelnk/application/x-rpm.desktop
share/mimelnk/application/x-ruby.desktop
share/mimelnk/application/x-sharedlib.desktop
share/mimelnk/application/x-shellscript.desktop
share/mimelnk/application/x-shockwave-flash.desktop
share/mimelnk/application/x-sqlite2.desktop
share/mimelnk/application/x-sqlite3.desktop
share/mimelnk/application/x-tar.desktop
share/mimelnk/application/x-tarz.desktop
share/mimelnk/application/x-tbz.desktop
@ -5279,6 +5439,7 @@ share/mimelnk/application/x-zerosize.desktop
share/mimelnk/application/x-zip.desktop
share/mimelnk/application/x-zoo.desktop
share/mimelnk/application/xhtml+xml.desktop
share/mimelnk/application/xml-dtd.desktop
share/mimelnk/application/xml.desktop
share/mimelnk/application/xsd.desktop
share/mimelnk/audio/
@ -5311,9 +5472,11 @@ share/mimelnk/audio/x-wav.desktop
share/mimelnk/image/
share/mimelnk/image/cgm.desktop
share/mimelnk/image/fax-g3.desktop
share/mimelnk/image/fits.desktop
share/mimelnk/image/gif.desktop
share/mimelnk/image/jp2.desktop
share/mimelnk/image/jpeg.desktop
share/mimelnk/image/jpg.desktop
share/mimelnk/image/pjpeg.desktop
share/mimelnk/image/png.desktop
share/mimelnk/image/svg+xml.desktop
@ -5322,8 +5485,10 @@ share/mimelnk/image/tiff.desktop
share/mimelnk/image/wmf.desktop
share/mimelnk/image/x-bmp.desktop
share/mimelnk/image/x-dds.desktop
share/mimelnk/image/x-djvu.desktop
share/mimelnk/image/x-eps.desktop
share/mimelnk/image/x-exr.desktop
share/mimelnk/image/x-hdr.desktop
share/mimelnk/image/x-ico.desktop
share/mimelnk/image/x-jng.desktop
share/mimelnk/image/x-msod.desktop
@ -5433,6 +5598,7 @@ share/services/file.protocol
share/services/ftp.protocol
share/services/ghelp.protocol
share/services/gif.kimgio
share/services/hdr.kimgio
share/services/help.protocol
share/services/http.protocol
share/services/http_cache_cleaner.desktop

View File

@ -0,0 +1,17 @@
@comment $OpenBSD: PLIST-cups,v 1.1 2005/11/29 14:00:12 espie Exp $
@conflict kdelibs-<3.5
bin/cupsdconf
bin/cupsdoprint
bin/make_driver_db_cups
${KDE}/cupsdconf.la
${KDE}/cupsdconf.so
${KDE}/kdeprint_cups.la
${KDE}/kdeprint_cups.so
lib/libkdeinit_cupsdconf.la
lib/libkdeinit_cupsdconf.so
share/apps/kdeprint/cups_logo.png
share/apps/kdeprint/cupsd.conf.template
share/apps/kdeprint/kde_logo.png
share/apps/kdeprint/plugins/cups.print
share/apps/kdeprint/preview-mini.png
share/apps/kdeprint/preview.png

View File

@ -1,7 +1,7 @@
$OpenBSD: patch-acinclude_m4,v 1.1 2005/09/18 12:21:07 espie Exp $
--- acinclude.m4.orig Sat Sep 10 21:33:23 2005
+++ acinclude.m4 Sun Sep 18 14:09:00 2005
@@ -6561,6 +6561,19 @@ AC_CACHE_VAL([lt_cv_sys_max_cmd_len], [d
$OpenBSD: patch-acinclude_m4,v 1.2 2005/11/29 14:00:13 espie Exp $
--- acinclude.m4.orig Mon Nov 21 10:06:52 2005
+++ acinclude.m4 Mon Nov 21 12:00:07 2005
@@ -6590,6 +6590,19 @@ AC_CACHE_VAL([lt_cv_sys_max_cmd_len], [d
lt_cv_sys_max_cmd_len=8192;
;;
@ -21,7 +21,7 @@ $OpenBSD: patch-acinclude_m4,v 1.1 2005/09/18 12:21:07 espie Exp $
*)
# If test is not a shell built-in, we'll probably end up computing a
# maximum length that is only half of the actual maximum length, but
@@ -8101,13 +8114,7 @@ nto-qnx*)
@@ -8130,13 +8143,7 @@ nto-qnx*)
;;
openbsd*)
@ -36,7 +36,7 @@ $OpenBSD: patch-acinclude_m4,v 1.1 2005/09/18 12:21:07 espie Exp $
;;
osf3* | osf4* | osf5*)
@@ -9081,6 +9088,22 @@ case $host_os in
@@ -9110,6 +9117,22 @@ case $host_os in
# Workaround some broken pre-1.5 toolchains
output_verbose_link_cmd='$CC -shared $CFLAGS -v conftest.$objext 2>&1 | grep conftest.$objext | $SED -e "s:-lgcc -lc -lgcc::"'
;;
@ -59,7 +59,7 @@ $OpenBSD: patch-acinclude_m4,v 1.1 2005/09/18 12:21:07 espie Exp $
osf3*)
case $cc_basename in
KCC)
@@ -11409,6 +11432,7 @@ EOF
@@ -11438,6 +11461,7 @@ EOF
_LT_AC_TAGVAR(hardcode_shlibpath_var, $1)=no
if test -z "`echo __ELF__ | $CC -E - | grep __ELF__`" || test "$host_os-$host_cpu" = "openbsd2.8-powerpc"; then
_LT_AC_TAGVAR(archive_cmds, $1)='$CC -shared $pic_flag -o $lib $compiler_flags $libobjs $deplibs'

View File

@ -1,7 +1,7 @@
$OpenBSD: patch-admin_cvs_sh,v 1.1 2005/09/18 12:21:07 espie Exp $
--- admin/cvs.sh.orig Sat Sep 10 16:28:22 2005
+++ admin/cvs.sh Sun Sep 18 14:09:34 2005
@@ -631,6 +631,10 @@ fi
$OpenBSD: patch-admin_cvs_sh,v 1.2 2005/11/29 14:00:13 espie Exp $
--- admin/cvs.sh.orig Sat Nov 19 10:19:55 2005
+++ admin/cvs.sh Mon Nov 21 12:00:07 2005
@@ -634,6 +634,10 @@ fi
# Call script to find autoconf and friends. Uses eval since the script outputs
# sh-compatible code.
eval `$admindir/detect-autoconf.pl`

View File

@ -1,7 +1,7 @@
$OpenBSD: patch-admin_ltmain_sh,v 1.1 2005/09/18 12:21:07 espie Exp $
--- admin/ltmain.sh.orig Sat Sep 10 16:28:22 2005
+++ admin/ltmain.sh Sun Sep 18 14:09:00 2005
@@ -1307,6 +1307,17 @@ EOF
$OpenBSD: patch-admin_ltmain_sh,v 1.2 2005/11/29 14:00:13 espie Exp $
--- admin/ltmain.sh.orig Wed Nov 9 10:30:02 2005
+++ admin/ltmain.sh Mon Nov 21 12:00:07 2005
@@ -1301,6 +1301,17 @@ EOF
continue
;;
@ -19,7 +19,7 @@ $OpenBSD: patch-admin_ltmain_sh,v 1.1 2005/09/18 12:21:07 espie Exp $
-module)
module=yes
continue
@@ -2003,6 +2014,30 @@ EOF
@@ -1997,6 +2008,30 @@ EOF
fi
continue
;;
--- kdesu/su.cpp.orig Sat Sep 10 10:27:02 2005
+++ kdesu/su.cpp Mon Nov 21 12:27:29 2005
@@ -41,19 +41,35 @@
#ifndef __PATH_SU
#define __PATH_SU "false"
@ -41,15 +41,15 @@ $OpenBSD: patch-kdesu_su_cpp,v 1.6 2004/09/18 09:36:44 espie Exp $
}
/*
* Execute a command with su(1).
*/
* Execute a command with su(1).
*/
int SuProcess::exec(const char *password, int check)
@@ -74,11 +90,19 @@ int SuProcess::exec(const char *password
setTerminal(true);
@@ -75,12 +91,20 @@ int SuProcess::exec(const char *password
QCStringList args;
+ if (d->m_useSudo)
+ {
+ args += "-S";
@ -58,51 +58,52 @@ $OpenBSD: patch-kdesu_su_cpp,v 1.6 2004/09/18 09:36:44 espie Exp $
+ args += "-u";
+ }
if ((m_Scheduler != SchedNormal) || (m_Priority > 50))
args += "root";
args += "root";
else
args += m_User;
args += m_User;
- args += "-c";
+ if (!d->m_useSudo)
+ args += "-c";
args += QCString(__KDE_BINDIR) + "/kdesu_stub";
args += "-";
@@ -91,7 +115,7 @@ int SuProcess::exec(const char *password
@@ -93,7 +117,7 @@ int SuProcess::exec(const char *password
}
// kdDebug(900) << k_lineinfo << "Call StubProcess::exec()" << endl;
- if (StubProcess::exec(command, args) < 0)
+ if (StubProcess::exec(d->m_useSudo ? __PATH_SUDO : __PATH_SU, args) < 0)
{
return check ? SuNotFound : -1;
return check ? SuNotFound : -1;
}
@@ -103,7 +127,8 @@ int SuProcess::exec(const char *password
@@ -105,7 +129,8 @@ int SuProcess::exec(const char *password
if (ret == error)
{
if (!check)
- kdError(900) << k_lineinfo << "Conversation with su failed\n";
if (!check)
- kdError(900) << k_lineinfo << "Conversation with su failed\n";
+ kdError(900) << k_lineinfo << "Conversation with " <<
+ (d->m_useSudo ? "sudo" : "su") << " failed\n";
return ret;
}
return ret;
}
if (check == NeedPassword)
@@ -201,6 +226,9 @@ int SuProcess::ConverseSU(const char *pa
kdDebug(900) << k_lineinfo << "Read line <" << more << ">" << endl;
@@ -211,6 +236,9 @@ int SuProcess::ConverseSU(const char *pa
kdDebug(900) << k_lineinfo << "Read line <" << more << ">" << endl;
}
+ if (d->m_useSudo && line != "Password:")
+ break;
+
// Match "Password: " with the regex ^[^:]+:[\w]*$.
const uint len = line.length();
for (i=0,j=0,colon=0; i<len; i++)
@@ -265,6 +293,9 @@ int SuProcess::ConverseSU(const char *pa
}
+ if (d->m_useSudo && line != "Password:")
+ break;
//////////////////////////////////////////////////////////////////////////
case HandleStub:
+ if (d->m_useSudo && line == "Password:")
+ return -1;
+
// Match "Password: " with the regex ^[^:]+:[\w]*$.
for (i=0,j=0,colon=0; i<line.length(); i++)
{
@@ -252,6 +280,9 @@ int SuProcess::ConverseSU(const char *pa
}
case HandleStub:
+ if (d->m_useSudo && line == "Password:")
+ return -1;
+
// Read till we get "kdesu_stub"
if (line == "kdesu_stub")
{
// Read till we get "kdesu_stub"
if (line == "kdesu_stub")
{

View File

@ -1,12 +0,0 @@
$OpenBSD: patch-kdeui_kmainwindow_cpp,v 1.3 2005/03/29 21:18:36 espie Exp $
@@ -41,19 +41,35 @@
}
/*
- * Execute a command with su(1).
+ * Execute a command with su(1) or sudo
*/
@@ -41,19 +41,35 @@
*/
-* Execute a command with su(1).
+* Execute a command with su(1) or sudo
*/
int SuProcess::exec(const char *password, int check)